native_toolchain_c library
A library to invoke the native C compiler installed on the host machine.
Classes
- BuildMode
- The build mode for compiling native code assets.
- CBuilder
- Specification for building an artifact with a C compiler.
- CLibrary
- Specification for building and linking a library with a C compiler.
- CLinker
- Specification for linking an artifact with a C linker.
- Language
- A programming language that can be selected for compilation of source files.
- LinkerOptions
- Options to pass to the linker.
- OptimizationLevel
- Optimization level for code compilation.